Learn R Programming

commons (version 0.0.1)

commons-package: commons: Agents for Data Analysis

Description

Implements large language model agents for answering questions about database tables. Agents combine 'DBI' database connections with table and column metadata from a data dictionary (https://data-dict.tidyverse.org/), using registered calculations when applicable and generating database queries otherwise. They can also be embedded in a 'Shiny' application.

Arguments

Author

Maintainer: Simon Couch simon.couch@posit.co (ORCID)

Authors:

Other contributors:

See Also