Implements large language model agents for answering questions about database tables. Agents combine 'DBI' database connections with table and column metadata from a data dictionary (https://data-dict.tidyverse.org/), using registered calculations when applicable and generating database queries otherwise. They can also be embedded in a 'Shiny' application.
Maintainer: Simon Couch simon.couch@posit.co (ORCID)
Authors:
Simon Couch simon.couch@posit.co (ORCID)
Sara Altman sara.altman@posit.co
Other contributors:
Garrick Aden-Buie garrick@posit.co (ORCID) [contributor]
Carson Sievert carson@posit.co (ORCID) [contributor]
Posit Software, PBC (ROR) [copyright holder, funder]
Useful links: